@@ -23,7 +23,6 @@ from idmtools.core.interfaces.inamed_entity import INamedEntity
 from idmtools.core.interfaces.irunnable_entity import IRunnableEntity
 from idmtools.core.logging import SUCCESS, NOTICE
 from idmtools.entities.itask import ITask
-from idmtools.core.interfaces.ientity import IEntity
 from idmtools.entities.platform_requirements import PlatformRequirements
 from idmtools.entities.templated_simulation import TemplatedSimulations
 from idmtools.registry.experiment_specification import ExperimentPluginSpecification, get_model_impl, \
@@ -36,6 +35,7 @@ from idmtools.utils.entities import get_default_tags
 if TYPE_CHECKING:  # pragma: no cover
     from idmtools.entities.iplatform import IPlatform
     from idmtools.entities.simulation import Simulation  # noqa: F401
+    from idmtools.entities.suite import Suite  # noqa: F401
 
 logger = getLogger(__name__)
 user_logger = getLogger('user')
@@ -205,8 +205,28 @@ class Experiment(IAssetsEnabled, INamedEntity, IRunnableEntity):
         """
         self.parent = suite
 
-    @IEntity.parent.setter
-    def parent(self, parent: 'IEntity'):
+    @property
+    def parent(self):
+        """
+        Return parent object for item.
+
+        Returns:
+            Parent Suite if set
+        """
+        if not self._parent:
+            self.parent_id = self.parent_id or self.suite_id
+            if not self.parent_id:
+                return None
+            if not self.platform:
+                from idmtools.core import NoPlatformException
+                raise NoPlatformException("The object has no platform set...")
+            suite = self.platform.get_item(self.parent_id, ItemType.SUITE, force=True)
+            suite.add_experiment(self)
+
+        return self._parent
+
+    @parent.setter
+    def parent(self, parent: 'Suite'):
         """
         Sets the parent object for Entity.
 
@@ -217,16 +237,9 @@ class Experiment(IAssetsEnabled, INamedEntity, IRunnableEntity):
             None
         """
         if parent is not None:
-            try:
-                experiments = getattr(parent, "experiments", None)
-            except AttributeError:
-                experiments = None
-
-            if experiments is None:
-                parent.experiments = [self]
-            elif self not in experiments:  # Avoid duplicate
-                experiments.append(self)
-        IEntity.parent.__set__(self, parent)
+            parent.add_experiment(self)
+        else:
+            self._parent = self.parent_id = self.suite_id = None
 
     def display(self):
         """
@@ -562,7 +575,8 @@ class Experiment(IAssetsEnabled, INamedEntity, IRunnableEntity):
         """
         p = super()._check_for_platform_from_context(platform)
         if 'wait_on_done' in run_opts:
-            raise TypeError("The 'wait_on_done' parameter has been removed in idmtools 1.8.0. Please update your code with 'wait_until_done'.")
+            raise TypeError(
+                "The 'wait_on_done' parameter has been removed in idmtools 1.8.0. Please update your code with 'wait_until_done'.")
         if regather_common_assets is None:
             regather_common_assets = p.is_regather_assets_on_modify()
         if regather_common_assets and not self.assets.is_editable():
@@ -576,7 +590,10 @@ class Experiment(IAssetsEnabled, INamedEntity, IRunnableEntity):
         run_opts['regather_common_assets'] = regather_common_assets
         p.run_items(self, **run_opts)
         if wait_until_done:
-            self.wait(wait_on_done_progress=wait_on_done_progress)
+            _refresh_interval = run_opts.get('refresh_interval', None)
+            if _refresh_interval is None:
+                _refresh_interval = p.refresh_interval
+            self.wait(wait_on_done_progress=wait_on_done_progress, refresh_interval=_refresh_interval)
 
     def to_dict(self):
         """
@@ -654,6 +671,7 @@ class Experiment(IAssetsEnabled, INamedEntity, IRunnableEntity):
         Returns:
             None
         """
+        # Append into underlying collection
         self.simulations.append(item)
 
     def add_simulations(self, item: Union[List['Simulation'], 'TemplatedSimulations']):  # noqa F821
@@ -695,6 +713,46 @@ class Experiment(IAssetsEnabled, INamedEntity, IRunnableEntity):
             **kwargs
         )
 
+    def check_duplicate(self, simulation_id: str) -> bool:
+        """
+        Check if a simulation ID already exists.
+        Args:
+            simulation_id: given Simulation ID
+        Returns:
+            True/False
+        """
+        if isinstance(self.simulations.items, (list, set)):
+            ids = [sim.id for sim in self.simulations.items]
+            return simulation_id in ids
+        elif isinstance(self.simulations.items, TemplatedSimulations):
+            return self.simulations.items.check_duplicate(simulation_id)
+        else:
+            return False
+
+    def clear_directory_cache(self):
+        """
+        Clear directory cache for Experiment and Simulations.
+        """
+        from idmtools.core.context import get_current_platform
+        platform = get_current_platform()
+
+        # Skip COMPS Platform
+        if platform and hasattr(platform, 'job_directory'):
+            # Clear experiment directory cache
+            r1 = getattr(self, "_platform_directory", None)
+            if r1:
+                self._platform_directory = None
+                logger.warning(f"The Experiment {self.uid} referenced a temporary directory {r1}.")
+
+            # Clear Children's directory cache
+            if isinstance(self.simulations.items, (list, set)):
+                for sim in self.simulations.items:
+                    sim._platform_directory = None
+            elif isinstance(self.simulations.items, TemplatedSimulations):
+                self.simulations.items.clear_extra_simulation_directory_cache()
+            else:
+                pass
+
 
 class ExperimentSpecification(ExperimentPluginSpecification):
     """
